@@ -33,11 +33,9 @@
 #  define KSTYLE_DEPRECATED_NO_EXPORT KSTYLE_NO_EXPORT KSTYLE_DEPRECATED
 #endif
 
-/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
-#if 0 /* DEFINE_NO_DEPRECATED */
-#  ifndef KSTYLE_NO_DEPRECATED
-#    define KSTYLE_NO_DEPRECATED
-#  endif
+#define DEFINE_NO_DEPRECATED 0
+#if DEFINE_NO_DEPRECATED
+# define KSTYLE_NO_DEPRECATED
 #endif
 
-#endif /* KSTYLE_EXPORT_H */
+#endif
